package com.da.dangan.mapper;

import java.util.List;
import com.da.dangan.domain.DaUserCatalog;

/**
 * 用户目录关联Mapper接口
 * 
 * @author hs
 * @date 2024-05-08
 */
public interface DaUserCatalogMapper 
{
    /**
     * 查询用户目录关联
     * 
     * @param userId 用户目录关联主键
     * @return 用户目录关联
     */
    public DaUserCatalog selectDaUserCatalogByUserId(Long userId);

    /**
     * 查询用户目录关联列表
     * 
     * @param daUserCatalog 用户目录关联
     * @return 用户目录关联集合
     */
    public List<DaUserCatalog> selectDaUserCatalogList(DaUserCatalog daUserCatalog);

    /**
     * 新增用户目录关联
     * 
     * @param daUserCatalog 用户目录关联
     * @return 结果
     */
    public int insertDaUserCatalog(DaUserCatalog daUserCatalog);

    /**
     * 修改用户目录关联
     * 
     * @param daUserCatalog 用户目录关联
     * @return 结果
     */
    public int updateDaUserCatalog(DaUserCatalog daUserCatalog);

    /**
     * 删除用户目录关联
     * 
     * @param userId 用户目录关联主键
     * @return 结果
     */
    public int deleteDaUserCatalogByUserId(Long userId);

    /**
     * 批量删除用户目录关联
     * 
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDaUserCatalogByUserIds(Long[] userIds);
}
